@@ -42,7 +42,7 @@ Activity::Activity(
 	int _activityGroupId,
 	const QStringList& _teachersNames,
 	const QString& _subjectName,
-	const QString& _activityTagName,
+	const QStringList& _activityTagsNames,
 	const QStringList& _studentsNames,
 	int _duration,
 	int _totalDuration,
@@ -54,7 +54,7 @@ Activity::Activity(
 	this->activityGroupId=_activityGroupId;
 	this->teachersNames = _teachersNames;
 	this->subjectName = _subjectName;
-	this->activityTagName = _activityTagName;
+	this->activityTagsNames = _activityTagsNames;
 	this->studentsNames = _studentsNames;
 	this->duration=_duration;
 	this->totalDuration=_totalDuration;
@@ -81,7 +81,7 @@ bool Activity::operator==(Activity& a)
 		return false;
 	if(this->subjectName != a.subjectName)
 		return false;
-	if(this->activityTagName != a.activityTagName)
+	if(this->activityTagsNames != a.activityTagsNames)
 		return false;
 	if(this->studentsNames != a.studentsNames)
 		return false;
@@ -188,7 +188,14 @@ void Activity::computeInternalStructure(Rules& r)
 	assert(this->subjectIndex>=0);
 
 	//activity tags
-	this->activityTagIndex = r.searchActivityTag(this->activityTagName);
+	this->iActivityTagsSet.clear();
+	foreach(QString tag, this->activityTagsNames){
+		assert(tag!="");
+		int index=r.searchActivityTag(tag);
+		assert(index>=0);
+		this->iActivityTagsSet.insert(index);
+	}
+	//this->activityTagIndex = r.searchActivityTag(this->activityTagName);
 
 	//students	
 	//this->nSubgroups=0;
@@ -300,7 +307,9 @@ QString Activity::getXmlDescription(Rules& r)
 	for(QStringList::Iterator it=this->teachersNames.begin(); it!=this->teachersNames.end(); it++)
 		s+="	<Teacher>" + protect(*it) + "</Teacher>\n";
 	s+="	<Subject>"+protect(this->subjectName)+"</Subject>\n";
-	s+="	<Activity_Tag>"+protect(this->activityTagName)+"</Activity_Tag>\n";
+
+	foreach(QString tag, this->activityTagsNames)
+		s+="	<Activity_Tag>"+protect(tag)+"</Activity_Tag>\n";
 
 	s+="	<Duration>"+QString::number(this->duration)+"</Duration>\n";
 	s+="	<Total_Duration>"+QString::number(this->totalDuration)+"</Total_Duration>\n";
@@ -312,10 +321,14 @@ QString Activity::getXmlDescription(Rules& r)
 		assert(this->parity==PARITY_FORTNIGHTLY);
 		s+="	<Fortnightly></Fortnightly>\n";
 	}*/
-	if(this->active==true)
-		s+="	<Active>yes</Active>\n";
-	else
-		s+="	<Active>no</Active>\n";
+	if(this->active==true){
+		//s+="	<Active>yes</Active>\n";
+		s+="	<Active>true</Active>\n";
+	}
+	else{
+		//s+="	<Active>no</Active>\n";
+		s+="	<Active>false</Active>\n";
+	}
 	for(QStringList::Iterator it=this->studentsNames.begin(); it!=this->studentsNames.end(); it++)
 		s+="	<Students>" + protect(*it) + "</Students>\n";
 
@@ -351,7 +364,18 @@ QString Activity::getDescription(Rules& r)
 
 	QString _subject=this->subjectName;
 	
-	QString _activityTag=this->activityTagName;
+	//QString _activityTag=this->activityTagName;
+	QString _activityTags=this->activityTagsNames.join(",");
+/*	QString _activityTags="";
+	if(this->activityTagsNames.count()>0){
+		bool begin=true;
+		foreach(QString tag, this->activityTagsNames){
+			if(!begin)
+				_activityTags+=",";
+			_activityTags+=tag;
+			begin=false;
+		}
+	}*/
 
 	QString _students="";
 	if(studentsNames.count()==0)
@@ -395,16 +419,16 @@ QString Activity::getDescription(Rules& r)
 	if(_indent)
 		s+="   ";
 
-	if(_activityTag!="" && this->isSplit() && _nstudents!=""){
+	if(_activityTags!="" && this->isSplit() && _nstudents!=""){
 		s+=QObject::tr("Act: T:%1, S:%2, AT:%3, St:%4, Id:%5, AGId:%6, D:%7, TD:%8, A:%9, NSt:%10",
 		 "Comment for translators (do not translate this comment):\n"
 		 "This is one of the 8 variants for description of an activity, depending on activity (if it has activity tag, etc.)"
 		 "Please be careful and respect arrangement.\n"
-		 "Activity: Teacher, Subject, Activity Tag, Students, Id, Activity Group Id, Duration, Total Duration, Active (yes/no), Number of Students")
-		 .arg(_teachers).arg(_subject).arg(_activityTag).arg(_students)
+		 "Activity: Teacher, Subject, Activity Tags, Students, Id, Activity Group Id, Duration, Total Duration, Active (yes/no), Number of Students")
+		 .arg(_teachers).arg(_subject).arg(_activityTags).arg(_students)
 		 .arg(_id).arg(_agid).arg(_duration).arg(_totalDuration).arg(_active).arg(_nstudents);
 	}
-	else if(_activityTag=="" && this->isSplit() && _nstudents!=""){
+	else if(_activityTags=="" && this->isSplit() && _nstudents!=""){
 		s+=QObject::tr("Act: T:%1, S:%2, St:%3, Id:%4, AGId:%5, D:%6, TD:%7, A:%8, NSt:%9",
 		 "Comment for translators (do not translate this comment):\n"
 		 "This is one of the 8 variants for description of an activity, depending on activity (if it has activity tag, etc.)"
@@ -413,16 +437,16 @@ QString Activity::getDescription(Rules& r)
 		 .arg(_teachers).arg(_subject).arg(_students)
 		 .arg(_id).arg(_agid).arg(_duration).arg(_totalDuration).arg(_active).arg(_nstudents);
 	}
-	else if(_activityTag!="" && !this->isSplit() && _nstudents!=""){
+	else if(_activityTags!="" && !this->isSplit() && _nstudents!=""){
 		s+=QObject::tr("Act: T:%1, S:%2, AT:%3, St:%4, Id:%5, D:%6, A:%7, NSt:%8",
 		 "Comment for translators (do not translate this comment):\n"
 		 "This is one of the 8 variants for description of an activity, depending on activity (if it has activity tag, etc.)"
 		 "Please be careful and respect arrangement.\n"
-		 "Activity: Teacher, Subject, Activity Tag, Students, Id, Duration, Active (yes/no), Number of Students")
-		 .arg(_teachers).arg(_subject).arg(_activityTag).arg(_students)
+		 "Activity: Teacher, Subject, Activity Tags, Students, Id, Duration, Active (yes/no), Number of Students")
+		 .arg(_teachers).arg(_subject).arg(_activityTags).arg(_students)
 		 .arg(_id).arg(_duration).arg(_active).arg(_nstudents);
 	}
-	else if(_activityTag=="" && !this->isSplit() && _nstudents!=""){
+	else if(_activityTags=="" && !this->isSplit() && _nstudents!=""){
 		s+=QObject::tr("Act: T:%1, S:%2, St:%3, Id:%4, D:%5, A:%6, NSt:%7",
 		 "Comment for translators (do not translate this comment):\n"
 		 "This is one of the 8 variants for description of an activity, depending on activity (if it has activity tag, etc.)"
@@ -431,16 +455,16 @@ QString Activity::getDescription(Rules& r)
 		 .arg(_teachers).arg(_subject).arg(_students)
 		 .arg(_id).arg(_duration).arg(_active).arg(_nstudents);
 	}
-	else if(_activityTag!="" && this->isSplit() && _nstudents==""){
+	else if(_activityTags!="" && this->isSplit() && _nstudents==""){
 		s+=QObject::tr("Act: T:%1, S:%2, AT:%3, St:%4, Id:%5, AGId:%6, D:%7, TD:%8, A:%9",
 		 "Comment for translators (do not translate this comment):\n"
 		 "This is one of the 8 variants for description of an activity, depending on activity (if it has activity tag, etc.)"
 		 "Please be careful and respect arrangement.\n"
-		 "Activity: Teacher, Subject, Activity Tag, Students, Id, Activity Group Id, Duration, Total Duration, Active (yes/no)")
-		 .arg(_teachers).arg(_subject).arg(_activityTag).arg(_students)
+		 "Activity: Teacher, Subject, Activity Tags, Students, Id, Activity Group Id, Duration, Total Duration, Active (yes/no)")
+		 .arg(_teachers).arg(_subject).arg(_activityTags).arg(_students)
 		 .arg(_id).arg(_agid).arg(_duration).arg(_totalDuration).arg(_active);
 	}
-	else if(_activityTag=="" && this->isSplit() && _nstudents==""){
+	else if(_activityTags=="" && this->isSplit() && _nstudents==""){
 		s+=QObject::tr("Act: T:%1, S:%2, St:%3, Id:%4, AGId:%5, D:%6, TD:%7, A:%8",
 		 "Comment for translators (do not translate this comment):\n"
 		 "This is one of the 8 variants for description of an activity, depending on activity (if it has activity tag, etc.)"
@@ -449,16 +473,16 @@ QString Activity::getDescription(Rules& r)
 		 .arg(_teachers).arg(_subject).arg(_students)
 		 .arg(_id).arg(_agid).arg(_duration).arg(_totalDuration).arg(_active);
 	}
-	else if(_activityTag!="" && !this->isSplit() && _nstudents==""){
+	else if(_activityTags!="" && !this->isSplit() && _nstudents==""){
 		s+=QObject::tr("Act: T:%1, S:%2, AT:%3, St:%4, Id:%5, D:%6, A:%7",
 		 "Comment for translators (do not translate this comment):\n"
 		 "This is one of the 8 variants for description of an activity, depending on activity (if it has activity tag, etc.)"
 		 "Please be careful and respect arrangement.\n"
-		 "Activity: Teacher, Subject, Activity Tag, Students, Id, Duration, Active (yes/no)")
-		 .arg(_teachers).arg(_subject).arg(_activityTag).arg(_students)
+		 "Activity: Teacher, Subject, Activity Tags, Students, Id, Duration, Active (yes/no)")
+		 .arg(_teachers).arg(_subject).arg(_activityTags).arg(_students)
 		 .arg(_id).arg(_duration).arg(_active);
 	}
-	else if(_activityTag=="" && !this->isSplit() && _nstudents==""){
+	else if(_activityTags=="" && !this->isSplit() && _nstudents==""){
 		s+=QObject::tr("Act: T:%1, S:%2, St:%3, Id:%4, D:%5, A:%6",
 		 "Comment for translators (do not translate this comment):\n"
 		 "This is one of the 8 variants for description of an activity, depending on activity (if it has activity tag, etc.)"
@@ -570,9 +594,12 @@ QString Activity::getDetailedDescription(Rules &r)
 		}
 	s+=QObject::tr("Subject=%1").arg(this->subjectName);
 	s+="\n";
-	if(this->activityTagName!=""){
-		s+=QObject::tr("Activity tag=%1").arg(this->activityTagName);
-		s+="\n";
+	foreach(QString tag, this->activityTagsNames){
+		//if(this->activityTagName!=""){
+			assert(tag!="");
+			s+=QObject::tr("Activity tag=%1").arg(tag);
+			s+="\n";
+		//}
 	}
 	if(studentsNames.count()==0){
 		s+=QObject::tr("No students sets for this activity");
