@@ -137,7 +137,7 @@ bool computeTeachersMaxGapsPerDayPercentage();
 ////////BEGIN activities same starting time
 extern QList<int> activitiesSameStartingTimeActivities[MAX_ACTIVITIES];
 extern QList<double> activitiesSameStartingTimePercentages[MAX_ACTIVITIES];
-void computeActivitiesSameStartingTime();
+bool computeActivitiesSameStartingTime();
 ////////END   activities same starting time
 
 
@@ -189,6 +189,17 @@ bool computeTeachersMaxHoursContinuously();
 ////////END   teacher(s) max hours continuously
 
 
+///////BEGIN teacher(s) activity tag max hours continuously
+extern bool haveTeachersActivityTagMaxHoursContinuously;
+
+extern QList<int> teachersActivityTagMaxHoursContinuouslyMaxHours[MAX_TEACHERS];
+extern QList<int> teachersActivityTagMaxHoursContinuouslyActivityTag[MAX_TEACHERS];
+extern QList<double> teachersActivityTagMaxHoursContinuouslyPercentage[MAX_TEACHERS];
+
+bool computeTeachersActivityTagMaxHoursContinuously();
+///////END   teacher(s) activity tag max hours continuously
+
+
 ////////BEGIN teacher(s) min hours daily
 extern double teachersMinHoursDailyPercentages[MAX_TEACHERS];
 extern int teachersMinHoursDailyMinHours[MAX_TEACHERS];
@@ -219,6 +230,17 @@ bool computeStudentsMaxHoursContinuously();
 ////////END   students (set) max hours continuously
 
 
+///////BEGIN students (set) activity tag max hours continuously
+extern bool haveStudentsActivityTagMaxHoursContinuously;
+
+extern QList<int> subgroupsActivityTagMaxHoursContinuouslyMaxHours[MAX_TOTAL_SUBGROUPS];
+extern QList<int> subgroupsActivityTagMaxHoursContinuouslyActivityTag[MAX_TOTAL_SUBGROUPS];
+extern QList<double> subgroupsActivityTagMaxHoursContinuouslyPercentage[MAX_TOTAL_SUBGROUPS];
+
+bool computeStudentsActivityTagMaxHoursContinuously();
+///////END   students (set) activity tag max hours continuously
+
+
 ////////BEGIN students (set) min hours daily
 extern double subgroupsMinHoursDailyPercentages[MAX_TOTAL_SUBGROUPS];
 extern int subgroupsMinHoursDailyMinHours[MAX_TOTAL_SUBGROUPS];
@@ -238,6 +260,13 @@ extern QList<int> inverseConstr2ActivitiesConsecutiveActivities[MAX_ACTIVITIES];
 //////////////END   2 activities consecutive
 
 
+//////////////BEGIN 2 activities grouped
+//index represents the first activity, value in array represents the second activity
+extern QList<double> constr2ActivitiesGroupedPercentages[MAX_ACTIVITIES];
+extern QList<int> constr2ActivitiesGroupedActivities[MAX_ACTIVITIES];
+void computeConstr2ActivitiesGrouped();
+
+
 //////////////BEGIN 2 activities ordered
 //index represents the first activity, value in array represents the second activity
 extern QList<double> constr2ActivitiesOrderedPercentages[MAX_ACTIVITIES];
