@@ -44,211 +44,72 @@ public:
 	
 	static void writeTimetableDataFile(const QString& filename);
 
-	/**
-	Function writing the subgroups' timetable xml format, to a file
-	*/
-	static void writeSubgroupsTimetableXml(const QString& xmlfilename);
+	//this function must be called before export html files (also statistics), because it compute the IDs
+	static void computeHashForIDs();
+private:
+	//the following functions return QStrings, because they are 'only' subfunctions to the writeXxxHtml functions
+	static QString writeHead(const bool java, const int placedActivities, const bool printInstitution);
+	static QString writeTOCDays(const bool detailed);
+	static QString writeStartTagTDofActivities(const Activity* act, const bool detailed, const bool colspan, const bool rowspan);
+	static QString writeSubjectAndActivityTags(const Activity* act, const QString startTag, const QString startTagAttribute, const bool activityTagsOnly);
+	static QString writeStudents(const Activity* act, const QString startTag, const QString startTagAttribute);
+	static QString writeTeachers(const Activity* act, const QString startTag, const QString startTagAttribute);
+	static QString writeRoom(const int ai, const QString startTag, const QString startTagAttribute);
+	static QString writeNotAvailable(const QString weight);
+	static QString writeEmpty();
 
-	/**
-	Function writing the teachers' timetable in xml format
-	*/
+	//the following functions write the conflicts text and the xml files
+	static void writeSubgroupsTimetableXml(const QString& xmlfilename);
 	static void writeTeachersTimetableXml(const QString& xmlfilename);
-		
-	/**
-	Function writing conflicts.txt
-	*/
+	static void writeActivitiesTimetableXml(const QString& xmlfilename);
 	static void writeConflictsTxt(const QString& filename, QString saveTime, int placedActivities);
 
-	/**
-	Function writing the index html-file
-	*/
+	//the following functions write the css and html timetable files
 	static void writeIndexHtml(const QString& htmlfilename, QString saveTime, int placedActivities);
-
-	/**
-	Function writing css stylesheet for each html-file
-	*/
 	static void writeStylesheetCss(const QString& htmlfilename, QString saveTime, int placedActivities);
-
-	/**
-	Function writing the subgroups' timetable html format, to a file
-	Days horizontal version.
-	*/
 	static void writeSubgroupsTimetableDaysHorizontalHtml(const QString& htmlfilename, QString saveTime, int placedActivities);
-
-	/**
-	Function writing the subgroups' timetable html format, to a file
-	Days vertical version.
-	*/
 	static void writeSubgroupsTimetableDaysVerticalHtml(const QString& htmlfilename, QString saveTime, int placedActivities);
-
-	/**
-	Function writing the subgroups' timetable html format, to a file
-	Time horizontal version.
-	*/
 	static void writeSubgroupsTimetableTimeHorizontalHtml(const QString& htmlfilename, QString saveTime, int placedActivities);
-
-	/**
-	Function writing the subgroups' timetable html format, to a file
-	Time vertical version.
-	*/
 	static void writeSubgroupsTimetableTimeVerticalHtml(const QString& htmlfilename, QString saveTime, int placedActivities);
-
-	/**
-	Function writing the groups' timetable html format, to a file
-	Days horizontal version.
-	*/
+	static void writeSubgroupsTimetableTimeHorizontalDailyHtml(const QString& htmlfilename, QString saveTime, int placedActivities);
+	static void writeSubgroupsTimetableTimeVerticalDailyHtml(const QString& htmlfilename, QString saveTime, int placedActivities);
 	static void writeGroupsTimetableDaysHorizontalHtml(const QString& htmlfilename, QString saveTime, int placedActivities);
-
-	/**
-	Function writing the groups' timetable html format, to a file
-	Days vertical version.
-	*/
 	static void writeGroupsTimetableDaysVerticalHtml(const QString& htmlfilename, QString saveTime, int placedActivities);
-
-	/**
-	Function writing the groups' timetable html format, to a file
-	Time horizontal version.
-	*/
 	static void writeGroupsTimetableTimeHorizontalHtml(const QString& htmlfilename, QString saveTime, int placedActivities);
-
-	/**
-	Function writing the groups' timetable html format, to a file
-	Time vertical version.
-	*/
 	static void writeGroupsTimetableTimeVerticalHtml(const QString& htmlfilename, QString saveTime, int placedActivities);
-
-	/**
-	Function writing the years' timetable html format, to a file
-	Days horizontal version.
-	*/
+	static void writeGroupsTimetableTimeHorizontalDailyHtml(const QString& htmlfilename, QString saveTime, int placedActivities);
+	static void writeGroupsTimetableTimeVerticalDailyHtml(const QString& htmlfilename, QString saveTime, int placedActivities);
 	static void writeYearsTimetableDaysHorizontalHtml(const QString& htmlfilename, QString saveTime, int placedActivities);
-
-	/**
-	Function writing the years' timetable html format, to a file
-	Days vertical version.
-	*/
 	static void writeYearsTimetableDaysVerticalHtml(const QString& htmlfilename, QString saveTime, int placedActivities);
-
-	/**
-	Function writing the years' timetable html format, to a file
-	Time horizontal version.
-	*/
 	static void writeYearsTimetableTimeHorizontalHtml(const QString& htmlfilename, QString saveTime, int placedActivities);
-
-	/**
-	Function writing the years' timetable html format, to a file
-	Time vertical version.
-	*/
 	static void writeYearsTimetableTimeVerticalHtml(const QString& htmlfilename, QString saveTime, int placedActivities);
-
-	/**
-	Function writing all activities' timetable html format, to a file
-	Days horizontal version.
-	*/
+	static void writeYearsTimetableTimeHorizontalDailyHtml(const QString& htmlfilename, QString saveTime, int placedActivities);
+	static void writeYearsTimetableTimeVerticalDailyHtml(const QString& htmlfilename, QString saveTime, int placedActivities);
 	static void writeAllActivitiesTimetableDaysHorizontalHtml(const QString& htmlfilename, QString saveTime, int placedActivities);
-
-	/**
-	Function writing all activities' timetable html format, to a file
-	Days vertical version.
-	*/
 	static void writeAllActivitiesTimetableDaysVerticalHtml(const QString& htmlfilename, QString saveTime, int placedActivities);
-
-
-	/**
-	Function writing all activities' timetable html format, to a file
-	Time horizontal version.
-	*/
 	static void writeAllActivitiesTimetableTimeHorizontalHtml(const QString& htmlfilename, QString saveTime, int placedActivities);
-
-	/**
-	Function writing all activities' timetable html format, to a file
-	Time vertical version.
-	*/
 	static void writeAllActivitiesTimetableTimeVerticalHtml(const QString& htmlfilename, QString saveTime, int placedActivities);
-	
-
-	/**
-	Function writing the teachers' timetable in html format
-	Days horizontal version
-	*/
+	static void writeAllActivitiesTimetableTimeHorizontalDailyHtml(const QString& htmlfilename, QString saveTime, int placedActivities);
+	static void writeAllActivitiesTimetableTimeVerticalDailyHtml(const QString& htmlfilename, QString saveTime, int placedActivities);
 	static void writeTeachersTimetableDaysHorizontalHtml(const QString& htmlfilename, QString saveTime, int placedActivities);
-
-	/**
-	Function writing the teachers' timetable in html format
-	Days vertical version
-	*/
 	static void writeTeachersTimetableDaysVerticalHtml(const QString& htmlfilename, QString saveTime, int placedActivities);
-
-	/**
-	Function writing the teachers' timetable in html format
-	Time horizontal version.
-	*/
 	static void writeTeachersTimetableTimeHorizontalHtml(const QString& htmlfilename, QString saveTime, int placedActivities);
-
-	/**
-	Function writing the teachers' timetable in html format
-	Time vertical version.
-	*/
 	static void writeTeachersTimetableTimeVerticalHtml(const QString& htmlfilename, QString saveTime, int placedActivities);
-
-	/**
-	Function writing the rooms' timetable in html format
-	Days horizontal version
-	*/
+	static void writeTeachersTimetableTimeHorizontalDailyHtml(const QString& htmlfilename, QString saveTime, int placedActivities);
+	static void writeTeachersTimetableTimeVerticalDailyHtml(const QString& htmlfilename, QString saveTime, int placedActivities);
 	static void writeRoomsTimetableDaysHorizontalHtml(const QString& htmlfilename, QString saveTime, int placedActivities);
-
-	/**
-	Function writing the rooms' timetable in html format
-	Days vertical version
-	*/
 	static void writeRoomsTimetableDaysVerticalHtml(const QString& htmlfilename, QString saveTime, int placedActivities);
-	
-	/**
-	Function writing the rooms' timetable in html format
-	Time horizontal version
-	*/
 	static void writeRoomsTimetableTimeHorizontalHtml(const QString& htmlfilename, QString saveTime, int placedActivities);
-
-	/**
-	Function writing the rooms' timetable in html format
-	Time vertical version
-	*/
 	static void writeRoomsTimetableTimeVerticalHtml(const QString& htmlfilename, QString saveTime, int placedActivities);
-
-	/**
-	Function writing the subjects' timetable in html format
-	Days horizontal version
-	*/
+	static void writeRoomsTimetableTimeHorizontalDailyHtml(const QString& htmlfilename, QString saveTime, int placedActivities);
+	static void writeRoomsTimetableTimeVerticalDailyHtml(const QString& htmlfilename, QString saveTime, int placedActivities);
 	static void writeSubjectsTimetableDaysHorizontalHtml(const QString& htmlfilename, QString saveTime, int placedActivities);
-
-	/**
-	Function writing the subjects' timetable in html format
-	Days vertical version
-	*/
 	static void writeSubjectsTimetableDaysVerticalHtml(const QString& htmlfilename, QString saveTime, int placedActivities);
-	
-	/**
-	Function writing the subjects' timetable in html format
-	Time horizontal version
-	*/
 	static void writeSubjectsTimetableTimeHorizontalHtml(const QString& htmlfilename, QString saveTime, int placedActivities);
-
-	/**
-	Function writing the subjects' timetable in html format
-	Time vertical version
-	*/
 	static void writeSubjectsTimetableTimeVerticalHtml(const QString& htmlfilename, QString saveTime, int placedActivities);
-
-	/**
-	Function writing the teachers' free periods timetable in html format
-	Days horizontal version
-	*/
+	static void writeSubjectsTimetableTimeHorizontalDailyHtml(const QString& htmlfilename, QString saveTime, int placedActivities);
+	static void writeSubjectsTimetableTimeVerticalDailyHtml(const QString& htmlfilename, QString saveTime, int placedActivities);
 	static void writeTeachersFreePeriodsTimetableDaysHorizontalHtml(const QString& htmlfilename, QString saveTime, int placedActivities);
-
-	/**
-	Function writing the teachers' free periods timetable in html format
-	Days vertical version
-	*/
 	static void writeTeachersFreePeriodsTimetableDaysVerticalHtml(const QString& htmlfilename, QString saveTime, int placedActivities);
 };
 
