@@ -1,8 +1,8 @@
 /***************************************************************************
                           addconstraint2activitiesgroupedform.h  -  description
                              -------------------
-    begin                : 15 May 2004
-    copyright            : (C) 2004 by Lalescu Liviu
+    begin                : Aug 21, 2007
+    copyright            : (C) 2007 by Lalescu Liviu
     email                : Please see http://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
  ***************************************************************************/
 
@@ -19,30 +19,36 @@
 #define ADDCONSTRAINT2ACTIVITIESGROUPEDFORM_H
 
 #include "addconstraint2activitiesgroupedform_template.h"
-#include "genetictimetable_defs.h"
-#include "genetictimetable.h"
+#include "timetable_defs.h"
+#include "timetable.h"
 #include "fet.h"
-#include "fetmainform.h"
 
-#include <qcombobox.h>
+#include <q3combobox.h>
 #include <qmessagebox.h>
-#include <qgroupbox.h>
-#include <qspinbox.h>
-#include <qcheckbox.h>
+#include <q3groupbox.h>
 #include <qpushbutton.h>
 #include <qlineedit.h>
-#include <qtextedit.h>
+#include <q3textedit.h>
+
+#include <QList>
 
 class AddConstraint2ActivitiesGroupedForm : public AddConstraint2ActivitiesGroupedForm_template  {
 public:
 	AddConstraint2ActivitiesGroupedForm();
 	~AddConstraint2ActivitiesGroupedForm();
 
-	void weightChanged();
-	void activitiesIdsTextChanged();
+	void updateActivitiesComboBox();
+
 	void constraintChanged();
-	
 	void addCurrentConstraint();
+	
+	bool filterOk(Activity* a);
+	void filterChanged();
+	
+private:
+	//the id's of the activities listed in the first and second activities combo
+	QList<int> firstActivitiesList;
+	QList<int> secondActivitiesList;
 };
 
 #endif
