@@ -25,6 +25,11 @@
 
 #include <QDesktopWidget>
 
+#include <QSet>
+#include "lockunlock.h"
+//extern QSet<int> idsOfLockedSpace;
+//extern QSet<int> idsOfPermanentlyLockedSpace;
+
 AddConstraintActivityPreferredRoomForm::AddConstraintActivityPreferredRoomForm()
 {
 	//setWindowFlags(Qt::Window);
@@ -35,6 +40,8 @@ AddConstraintActivityPreferredRoomForm::AddConstraintActivityPreferredRoomForm()
 	move(xx, yy);*/
 	centerWidgetOnScreen(this);
 	
+	//permTextLabel->setWordWrap(true);
+	
 	teachersComboBox->insertItem("");
 	for(int i=0; i<gt.rules.teachersList.size(); i++){
 		Teacher* tch=gt.rules.teachersList[i];
@@ -104,7 +111,8 @@ bool AddConstraintActivityPreferredRoomForm::filterOk(Activity* act)
 		ok=false;
 		
 	//activity tag
-	if(sbtn!="" && sbtn!=act->activityTagName)
+//	if(sbtn!="" && sbtn!=act->activityTagName)
+	if(sbtn!="" && !act->activityTagsNames.contains(sbtn))
 		ok=false;
 		
 	//students
@@ -191,7 +199,7 @@ void AddConstraintActivityPreferredRoomForm::addConstraint()
 	}
 	QString room=roomsComboBox->currentText();
 
-	ctr=new ConstraintActivityPreferredRoom(weight, id, room);
+	ctr=new ConstraintActivityPreferredRoom(weight, id, room, permLockedCheckBox->isChecked());
 
 	bool tmp3=gt.rules.addSpaceConstraint(ctr);
 	if(tmp3){
@@ -199,6 +207,13 @@ void AddConstraintActivityPreferredRoomForm::addConstraint()
 		s+="\n";
 		s+=ctr->getDetailedDescription(gt.rules);
 		QMessageBox::information(this, QObject::tr("FET information"), s);
+		
+		/*if(permLockedCheckBox->isChecked()) wrong, must take care of weight==100.0
+			idsOfPermanentlyLockedSpace.insert(id);
+		else
+			idsOfLockedSpace.insert(id);*/
+		LockUnlock::computeLockedUnlockedActivitiesOnlySpace(); //safer
+		LockUnlock::increaseCommunicationSpinBox();
 	}
 	else{
 		QMessageBox::warning(this, QObject::tr("FET information"),
