@@ -1,8 +1,8 @@
 /***************************************************************************
                           addconstraintstudentssetintervalmaxdaysperweekform.cpp  -  description
                              -------------------
-    begin                : Feb 11, 2005
-    copyright            : (C) 2005 by Lalescu Liviu
+    begin                : 2008
+    copyright            : (C) 2008 by Lalescu Liviu
     email                : Please see http://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
  ***************************************************************************/
 
@@ -22,26 +22,39 @@
 #include <qlabel.h>
 #include <qlineedit.h>
 
-#define yesNo(x)	((x)==0?QObject::tr("no"):QObject::tr("yes"))
+#include <QDesktopWidget>
 
 AddConstraintStudentsSetIntervalMaxDaysPerWeekForm::AddConstraintStudentsSetIntervalMaxDaysPerWeekForm()
 {
-	updatePeriodGroupBox();
-	updateStudentsSetComboBox();
+	//setWindowFlags(Qt::Window);
+	/*setWindowFlags(windowFlags() | Qt::WindowMinMaxButtonsHint);
+	QDesktopWidget* desktop=QApplication::desktop();
+	int xx=desktop->width()/2 - frameGeometry().width()/2;
+	int yy=desktop->height()/2 - frameGeometry().height()/2;
+	move(xx, yy);*/
+	centerWidgetOnScreen(this);
+	
+	updateMaxDaysSpinBox();
+	updateStudentsComboBox();
+	updateStartHoursComboBox();
+	updateEndHoursComboBox();
 }
 
 AddConstraintStudentsSetIntervalMaxDaysPerWeekForm::~AddConstraintStudentsSetIntervalMaxDaysPerWeekForm()
 {
 }
 
-void AddConstraintStudentsSetIntervalMaxDaysPerWeekForm::updateStudentsSetComboBox()
+void AddConstraintStudentsSetIntervalMaxDaysPerWeekForm::updateStudentsComboBox()
 {
 	studentsComboBox->clear();	
-	for(StudentsYear* sty=gt.rules.yearsList.first(); sty; sty=gt.rules.yearsList.next()){
+	for(int i=0; i<gt.rules.yearsList.size(); i++){
+		StudentsYear* sty=gt.rules.yearsList[i];
 		studentsComboBox->insertItem(sty->name);
-		for(StudentsGroup* stg=sty->groupsList.first(); stg; stg=sty->groupsList.next()){
+		for(int j=0; j<sty->groupsList.size(); j++){
+			StudentsGroup* stg=sty->groupsList[j];
 			studentsComboBox->insertItem(stg->name);
-			for(StudentsSubgroup* sts=stg->subgroupsList.first(); sts; sts=stg->subgroupsList.next()){
+			for(int k=0; k<stg->subgroupsList.size(); k++){
+				StudentsSubgroup* sts=stg->subgroupsList[k];
 				studentsComboBox->insertItem(sts->name);
 			}
 		}
@@ -50,65 +63,58 @@ void AddConstraintStudentsSetIntervalMaxDaysPerWeekForm::updateStudentsSetComboB
 	constraintChanged();
 }
 
-void AddConstraintStudentsSetIntervalMaxDaysPerWeekForm::updatePeriodGroupBox(){
-	startHourComboBox->clear();
-	for(int i=0; i<=gt.rules.nHoursPerDay; i++)
-		startHourComboBox->insertItem(gt.rules.hoursOfTheDay[i]);
-
-	endHourComboBox->clear();
-	for(int i=0; i<=gt.rules.nHoursPerDay; i++)
-		endHourComboBox->insertItem(gt.rules.hoursOfTheDay[i]);
-
+void AddConstraintStudentsSetIntervalMaxDaysPerWeekForm::updateMaxDaysSpinBox(){
 	maxDaysSpinBox->setMinValue(0);
 	maxDaysSpinBox->setMaxValue(gt.rules.nDaysPerWeek);
 	maxDaysSpinBox->setValue(gt.rules.nDaysPerWeek);
 }
 
+void AddConstraintStudentsSetIntervalMaxDaysPerWeekForm::updateStartHoursComboBox()
+{
+	startHourComboBox->clear();
+	for(int i=0; i<gt.rules.nHoursPerDay; i++)
+		startHourComboBox->insertItem(gt.rules.hoursOfTheDay[i]);
+	startHourComboBox->setCurrentItem(gt.rules.nHoursPerDay-1);
+	
+	constraintChanged();
+}
+
+void AddConstraintStudentsSetIntervalMaxDaysPerWeekForm::updateEndHoursComboBox()
+{
+	endHourComboBox->clear();
+	for(int i=0; i<gt.rules.nHoursPerDay; i++)
+		endHourComboBox->insertItem(gt.rules.hoursOfTheDay[i]);
+	endHourComboBox->insertItem(tr("End of day"));
+	endHourComboBox->setCurrentItem(gt.rules.nHoursPerDay);
+	
+	constraintChanged();
+}
+
 void AddConstraintStudentsSetIntervalMaxDaysPerWeekForm::constraintChanged()
 {
 	QString s;
-	s+=QObject::tr("Current constraint:");
+	s+=tr("Current constraint:");
 	s+="\n";
 
 	double weight;
 	QString tmp=weightLineEdit->text();
 	sscanf(tmp, "%lf", &weight);
-	s+=QObject::tr("Weight=%1").arg(weight);
+	s+=tr("Weight (percentage)=%1").arg(weight);
 	s+="\n";
 
-	bool compulsory=false;
-	if(compulsoryCheckBox->isChecked())
-		compulsory=true;
-	s+=QObject::tr("Compulsory=%1").arg(yesNo(compulsory));
+	s+=tr("Students set interval max days per week");
+	s+="\n";
+	s+=tr("Students set=%1").arg(studentsComboBox->currentText());
 	s+="\n";
 
-	s+=QObject::tr("Students set interval max days per week");
-	s+="\n";
-	s+=QObject::tr("Students set=%1").arg(studentsComboBox->currentText());
+	s+=tr("Interval start hour=%1").arg(startHourComboBox->currentText());
 	s+="\n";
 
-	s+=QObject::tr("Max days=%1").arg(maxDaysSpinBox->value());
+	s+=tr("Interval end hour=%1").arg(endHourComboBox->currentText());
 	s+="\n";
 
-	int startHour=startHourComboBox->currentItem();
-	if(startHour<0 || startHour>gt.rules.nHoursPerDay){
-		s+=QObject::tr("Invalid start hour");
-		s+="\n";
-	}
-	else{
-		s+=QObject::tr("Start hour:%1").arg(startHourComboBox->currentText());
-		s+="\n";
-	}
-
-	int endHour=endHourComboBox->currentItem();
-	if(endHour<0 || endHour>gt.rules.nHoursPerDay){
-		s+=QObject::tr("Invalid end hour");
-		s+="\n";
-	}
-	else{
-		s+=QObject::tr("End hour:%1").arg(endHourComboBox->currentText());
-		s+="\n";
-	}
+	s+=tr("Max days per week=%1").arg(maxDaysSpinBox->value());
+	s+="\n";
 
 	currentConstraintTextEdit->setText(s);
 }
@@ -120,54 +126,58 @@ void AddConstraintStudentsSetIntervalMaxDaysPerWeekForm::addCurrentConstraint()
 	double weight;
 	QString tmp=weightLineEdit->text();
 	sscanf(tmp, "%lf", &weight);
-	if(weight<0.0){
-		QMessageBox::warning(this, QObject::tr("FET information"),
-			QObject::tr("Invalid weight"));
+	if(weight<0.0 || weight>100.0){
+		QMessageBox::warning(this, tr("FET information"),
+			tr("Invalid weight (percentage)"));
+		return;
+	}
+	if(weight!=100.0){
+		QMessageBox::warning(this, tr("FET information"),
+			tr("Invalid weight (percentage) - it has to be 100%"));
 		return;
 	}
 
-	bool compulsory=false;
+	/*bool compulsory=false;
 	if(compulsoryCheckBox->isChecked())
-		compulsory=true;
+		compulsory=true;*/
 
-	int startHour=startHourComboBox->currentItem();
-	if(startHour<0 || startHour>gt.rules.nHoursPerDay){
-		QMessageBox::warning(this, QObject::tr("FET information"),
-			QObject::tr("Invalid start hour"));
-		return;
-	}
-	int endHour=-1;
-	endHour=endHourComboBox->currentItem();
-	if(endHour<0 || endHour>gt.rules.nHoursPerDay){
-		QMessageBox::warning(this, QObject::tr("FET information"),
-			QObject::tr("Invalid end hour"));
-		return;
-	}
-	if(endHour<=startHour){
-		QMessageBox::warning(this, QObject::tr("FET information"),
-			QObject::tr("End hour <= start hour - impossible"));
-		return;
-	}
+	int max_days=maxDaysSpinBox->value();
 
 	QString students_name=studentsComboBox->currentText();
 	StudentsSet* s=gt.rules.searchStudentsSet(students_name);
 	if(s==NULL){
-		QMessageBox::warning(this, QObject::tr("FET information"),
-			QObject::tr("Invalid students set"));
+		QMessageBox::warning(this, tr("FET information"),
+			tr("Invalid students set"));
 		return;
 	}
 	
-	int maxDays=maxDaysSpinBox->value();
+	int startHour=startHourComboBox->currentItem();
+	int endHour=endHourComboBox->currentItem();
+	if(startHour<0 || startHour>=gt.rules.nHoursPerDay){
+		QMessageBox::warning(this, tr("FET information"),
+			tr("Start hour invalid"));
+		return;
+	}
+	if(endHour<0 || endHour>gt.rules.nHoursPerDay){
+		QMessageBox::warning(this, tr("FET information"),
+			tr("End hour invalid"));
+		return;
+	}
+	if(endHour<=startHour){
+		QMessageBox::warning(this, tr("FET information"),
+			tr("Start hour cannot be greater or equal than end hour"));
+		return;
+	}
 
-	ctr=new ConstraintStudentsSetIntervalMaxDaysPerWeek(weight, compulsory, students_name, startHour, endHour, maxDays);
+	ctr=new ConstraintStudentsSetIntervalMaxDaysPerWeek(weight, /*compulsory,*/ max_days, students_name, startHour, endHour);
 
 	bool tmp2=gt.rules.addTimeConstraint(ctr);
 	if(tmp2)
-		QMessageBox::information(this, QObject::tr("FET information"),
-			QObject::tr("Constraint added"));
+		QMessageBox::information(this, tr("FET information"),
+			tr("Constraint added"));
 	else{
-		QMessageBox::warning(this, QObject::tr("FET information"),
-			QObject::tr("Constraint NOT added - please report error"));
+		QMessageBox::warning(this, tr("FET information"),
+			tr("Constraint NOT added - please report error"));
 		delete ctr;
 	}
 }
