@@ -28,12 +28,13 @@
 AddConstraintSubjectPreferredRoomsForm::AddConstraintSubjectPreferredRoomsForm()
 {
 	//setWindowFlags(Qt::Window);
-	setWindowFlags(windowFlags() | Qt::WindowMinMaxButtonsHint);
+	/*setWindowFlags(windowFlags() | Qt::WindowMinMaxButtonsHint);
 	QDesktopWidget* desktop=QApplication::desktop();
 	int xx=desktop->width()/2 - frameGeometry().width()/2;
 	int yy=desktop->height()/2 - frameGeometry().height()/2;
-	move(xx, yy);
-
+	move(xx, yy);*/
+	centerWidgetOnScreen(this);
+	
 	updateRoomsListBox();
 	
 	for(int i=0; i<gt.rules.subjectsList.size(); i++){
