@@ -116,7 +116,8 @@ bool ConstraintActivityEndsStudentsDayForm::filterOk(TimeConstraint* ctr)
 			found=false;
 	
 		//activity tag
-		if(sbtn!="" && sbtn!=act->activityTagName)
+//		if(sbtn!="" && sbtn!=act->activityTagName)
+		if(sbtn!="" && !act->activityTagsNames.contains(sbtn))
 			found=false;
 	
 		//students
