@@ -134,7 +134,8 @@ bool ConstraintActivityPreferredRoomsForm::filterOk(SpaceConstraint* ctr)
 			found=false;
 	
 		//activity tag
-		if(sbtn!="" && sbtn!=act->activityTagName)
+//		if(sbtn!="" && sbtn!=act->activityTagName)
+		if(sbtn!="" && !act->activityTagsNames.contains(sbtn))
 			found=false;
 	
 		//students
