@@ -1,8 +1,8 @@
 /***************************************************************************
                           constraintstudentssetintervalmaxdaysperweekform.cpp  -  description
                              -------------------
-    begin                : Feb 11, 2005
-    copyright            : (C) 2005 by Lalescu Liviu
+    begin                : 2008
+    copyright            : (C) 2008 by Lalescu Liviu
     email                : Please see http://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
  ***************************************************************************/
 
@@ -19,20 +19,33 @@
 #include "addconstraintstudentssetintervalmaxdaysperweekform.h"
 #include "modifyconstraintstudentssetintervalmaxdaysperweekform.h"
 
+#include <QDesktopWidget>
+
 ConstraintStudentsSetIntervalMaxDaysPerWeekForm::ConstraintStudentsSetIntervalMaxDaysPerWeekForm()
 {
+	//setWindowFlags(Qt::Window);
+	/*setWindowFlags(windowFlags() | Qt::WindowMinMaxButtonsHint);
+	QDesktopWidget* desktop=QApplication::desktop();
+	int xx=desktop->width()/2 - frameGeometry().width()/2;
+	int yy=desktop->height()/2 - frameGeometry().height()/2;
+	move(xx, yy);*/
+	centerWidgetOnScreen(this);
+	
 	studentsComboBox->insertItem("");
-	for(StudentsYear* sty=gt.rules.yearsList.first(); sty; sty=gt.rules.yearsList.next()){
+
+	for(int i=0; i<gt.rules.yearsList.size(); i++){
+		StudentsYear* sty=gt.rules.yearsList[i];
 		studentsComboBox->insertItem(sty->name);
-		for(StudentsGroup* stg=sty->groupsList.first(); stg; stg=sty->groupsList.next()){
+		for(int j=0; j<sty->groupsList.size(); j++){
+			StudentsGroup* stg=sty->groupsList[j];
 			studentsComboBox->insertItem(stg->name);
-			for(StudentsSubgroup* sts=stg->subgroupsList.first(); sts; sts=stg->subgroupsList.next()){
-				studentsComboBox->insertItem(sts->name);		
-			}		
+			for(int k=0; k<stg->subgroupsList.size(); k++){
+				StudentsSubgroup* sts=stg->subgroupsList[k];
+				studentsComboBox->insertItem(sts->name);
+			}
 		}
 	}
 
-	this->visibleConstraintsList.setAutoDelete(false);
 	this->filterChanged();
 }
 
@@ -54,18 +67,20 @@ void ConstraintStudentsSetIntervalMaxDaysPerWeekForm::filterChanged()
 {
 	this->visibleConstraintsList.clear();
 	constraintsListBox->clear();
-	for(TimeConstraint* ctr=gt.rules.timeConstraintsList.first(); ctr; ctr=gt.rules.timeConstraintsList.next())
+	for(int i=0; i<gt.rules.timeConstraintsList.size(); i++){
+		TimeConstraint* ctr=gt.rules.timeConstraintsList[i];
 		if(filterOk(ctr)){
 			visibleConstraintsList.append(ctr);
 			constraintsListBox->insertItem(ctr->getDescription(gt.rules));
 		}
+	}
 }
 
 void ConstraintStudentsSetIntervalMaxDaysPerWeekForm::constraintChanged(int index)
 {
 	if(index<0)
 		return;
-	assert((uint)(index)<this->visibleConstraintsList.count());
+	assert(index<this->visibleConstraintsList.size());
 	TimeConstraint* ctr=this->visibleConstraintsList.at(index);
 	assert(ctr!=NULL);
 	currentConstraintTextEdit->setText(ctr->getDetailedDescription(gt.rules));
@@ -73,8 +88,8 @@ void ConstraintStudentsSetIntervalMaxDaysPerWeekForm::constraintChanged(int inde
 
 void ConstraintStudentsSetIntervalMaxDaysPerWeekForm::addConstraint()
 {
-	AddConstraintStudentsSetIntervalMaxDaysPerWeekForm *addConstraintStudentsSetIntervalMaxDaysPerWeekForm=new AddConstraintStudentsSetIntervalMaxDaysPerWeekForm();
-	addConstraintStudentsSetIntervalMaxDaysPerWeekForm->exec();
+	AddConstraintStudentsSetIntervalMaxDaysPerWeekForm *form=new AddConstraintStudentsSetIntervalMaxDaysPerWeekForm();
+	form->exec();
 
 	filterChanged();
 	
@@ -85,14 +100,14 @@ void ConstraintStudentsSetIntervalMaxDaysPerWeekForm::modifyConstraint()
 {
 	int i=constraintsListBox->currentItem();
 	if(i<0){
-		QMessageBox::information(this, QObject::tr("FET information"), QObject::tr("Invalid selected constraint"));
+		QMessageBox::information(this, tr("FET information"), tr("Invalid selected constraint"));
 		return;
 	}
 	TimeConstraint* ctr=this->visibleConstraintsList.at(i);
 
-	ModifyConstraintStudentsSetIntervalMaxDaysPerWeekForm *modifyConstraintStudentsSetIntervalMaxDaysPerWeekForm
+	ModifyConstraintStudentsSetIntervalMaxDaysPerWeekForm *form
 	 = new ModifyConstraintStudentsSetIntervalMaxDaysPerWeekForm((ConstraintStudentsSetIntervalMaxDaysPerWeek*)ctr);
-	modifyConstraintStudentsSetIntervalMaxDaysPerWeekForm->exec();
+	form->exec();
 
 	filterChanged();
 	constraintsListBox->setCurrentItem(i);
@@ -102,17 +117,17 @@ void ConstraintStudentsSetIntervalMaxDaysPerWeekForm::removeConstraint()
 {
 	int i=constraintsListBox->currentItem();
 	if(i<0){
-		QMessageBox::information(this, QObject::tr("FET information"), QObject::tr("Invalid selected constraint"));
+		QMessageBox::information(this, tr("FET information"), tr("Invalid selected constraint"));
 		return;
 	}
 	TimeConstraint* ctr=this->visibleConstraintsList.at(i);
 	QString s;
-	s=QObject::tr("Removing constraint:\n");
+	s=tr("Removing constraint:\n");
 	s+=ctr->getDetailedDescription(gt.rules);
-	s+=QObject::tr("\nAre you sure?");
+	s+=tr("\nAre you sure?");
 
-	switch( QMessageBox::warning( this, QObject::tr("FET warning"),
-		s, QObject::tr("OK"), QObject::tr("Cancel"), 0, 0, 1 ) ){
+	switch( QMessageBox::warning( this, tr("FET warning"),
+		s, tr("OK"), tr("Cancel"), 0, 0, 1 ) ){
 	case 0: // The user clicked the OK again button or pressed Enter
 		gt.rules.removeTimeConstraint(ctr);
 		filterChanged();
