@@ -41,7 +41,7 @@ public:
 	ModifyConstraintActivitiesSameStartingTimeForm(ConstraintActivitiesSameStartingTime* ctr);
 	~ModifyConstraintActivitiesSameStartingTimeForm();
 
-	void updateActivitiesListBox();
+	//void updateActivitiesListBox();
 	
 	void addActivity();
 	void removeActivity();
@@ -49,6 +49,10 @@ public:
 	void ok();
 	void cancel();
 	
+	bool filterOk(Activity* ac);
+	
+	void filterChanged();
+	
 private:
 	ConstraintActivitiesSameStartingTime* _ctr;
 	//the id's of the activities listed in the activities list
