@@ -26,6 +26,8 @@
 
 #define yesNo(x)	((x)==0?QObject::tr("no"):QObject::tr("yes"))
 
+#include "lockunlock.h"
+
 ModifyConstraintActivityPreferredStartingTimeForm::ModifyConstraintActivityPreferredStartingTimeForm(ConstraintActivityPreferredStartingTime* ctr)
 {
 	//setWindowFlags(Qt::Window);
@@ -36,6 +38,8 @@ ModifyConstraintActivityPreferredStartingTimeForm::ModifyConstraintActivityPrefe
 	move(xx, yy);*/
 	centerWidgetOnScreen(this);
 	
+	//permTextLabel->setWordWrap(true);
+	
 	this->_ctr=ctr;
 	
 	//compulsoryCheckBox->setChecked(ctr->compulsory);
@@ -80,9 +84,11 @@ ModifyConstraintActivityPreferredStartingTimeForm::ModifyConstraintActivityPrefe
 	updatePeriodGroupBox();
 	updateActivitiesComboBox();
 
-	dayComboBox->setCurrentItem(ctr->day+1);
-	startHourComboBox->setCurrentItem(ctr->hour+1);
-
+	dayComboBox->setCurrentItem(ctr->day);
+	startHourComboBox->setCurrentItem(ctr->hour);
+	
+	permLockedCheckBox->setChecked(this->_ctr->permanentlyLocked);
+	
 	constraintChanged();
 }
 
@@ -115,7 +121,8 @@ bool ModifyConstraintActivityPreferredStartingTimeForm::filterOk(Activity* act)
 		ok=false;
 		
 	//activity tag
-	if(sbtn!="" && sbtn!=act->activityTagName)
+//	if(sbtn!="" && sbtn!=act->activityTagName)
+	if(sbtn!="" && !act->activityTagsNames.contains(sbtn))
 		ok=false;
 		
 	//students
@@ -161,12 +168,12 @@ void ModifyConstraintActivityPreferredStartingTimeForm::updateActivitiesComboBox
 
 void ModifyConstraintActivityPreferredStartingTimeForm::updatePeriodGroupBox(){
 	startHourComboBox->clear();
-	startHourComboBox->insertItem(QObject::tr("Any"));
+	//startHourComboBox->insertItem(QObject::tr("Any"));
 	for(int i=0; i<gt.rules.nHoursPerDay; i++)
 		startHourComboBox->insertItem(gt.rules.hoursOfTheDay[i]);
 
 	dayComboBox->clear();
-	dayComboBox->insertItem(QObject::tr("Any"));
+	//dayComboBox->insertItem(QObject::tr("Any"));
 	for(int i=0; i<gt.rules.nDaysPerWeek; i++)
 		dayComboBox->insertItem(gt.rules.daysOfTheWeek[i]);
 }
@@ -207,7 +214,7 @@ void ModifyConstraintActivityPreferredStartingTimeForm::constraintChanged()
 	}
 
 	int day=dayComboBox->currentItem();
-	if(day<0 || day>gt.rules.nDaysPerWeek){
+	if(day<0 || day>=gt.rules.nDaysPerWeek){
 		s+=QObject::tr("Invalid day");
 		s+="\n";
 	}
@@ -217,7 +224,7 @@ void ModifyConstraintActivityPreferredStartingTimeForm::constraintChanged()
 	}
 
 	int startHour=startHourComboBox->currentItem();
-	if(startHour<0 || startHour>gt.rules.nHoursPerDay){
+	if(startHour<0 || startHour>=gt.rules.nHoursPerDay){
 		s+=QObject::tr("Invalid start hour");
 		s+="\n";
 	}
@@ -225,6 +232,14 @@ void ModifyConstraintActivityPreferredStartingTimeForm::constraintChanged()
 		s+=QObject::tr("Start hour:%1").arg(startHourComboBox->currentText());
 		s+="\n";
 	}
+	
+	if(permLockedCheckBox->isChecked()){
+		s+=QObject::tr("Permanently locked (cannot be unlocked from the 'Timetable' menu)");
+	}
+	else{
+		s+=QObject::tr("Not permanently locked (can be unlocked from the 'Timetable' menu)");
+	}
+	s+="\n";
 
 	currentConstraintTextEdit->setText(s);
 }
@@ -245,23 +260,23 @@ void ModifyConstraintActivityPreferredStartingTimeForm::ok()
 		compulsory=true;*/
 
 	int day=dayComboBox->currentItem();
-	if(day<0 || day>gt.rules.nDaysPerWeek){
+	if(day<0 || day>=gt.rules.nDaysPerWeek){
 		QMessageBox::warning(this, QObject::tr("FET information"),
 			QObject::tr("Invalid day"));
 		return;
 	}
 	int startHour=startHourComboBox->currentItem();
-	if(startHour<0 || startHour>gt.rules.nHoursPerDay){
+	if(startHour<0 || startHour>=gt.rules.nHoursPerDay){
 		QMessageBox::warning(this, QObject::tr("FET information"),
 			QObject::tr("Invalid start hour"));
 		return;
 	}
 
-	if(startHour==0 && day==0){
+/*	if(startHour==0 && day==0){
 		QMessageBox::warning(this, QObject::tr("FET information"),
 			QObject::tr("Please specify at least a day or an hour"));
 		return;
-	}
+	}*/
 	
 	int tmp2=activitiesComboBox->currentItem();
 	assert(tmp2<gt.rules.activitiesList.size());
@@ -287,11 +302,16 @@ void ModifyConstraintActivityPreferredStartingTimeForm::ok()
 
 	this->_ctr->weightPercentage=weight;
 	//this->_ctr->compulsory=compulsory;
-	this->_ctr->day=day-1;
-	this->_ctr->hour=startHour-1;
+	this->_ctr->day=day;
+	this->_ctr->hour=startHour;
 	this->_ctr->activityId=id;
 	
+	this->_ctr->permanentlyLocked=permLockedCheckBox->isChecked();
+	
 	gt.rules.internalStructureComputed=false;
+	
+	LockUnlock::computeLockedUnlockedActivitiesOnlyTime();
+	LockUnlock::increaseCommunicationSpinBox();
 
 	this->close();
 }
