@@ -43,7 +43,7 @@ public:
 	ModifyConstraintMinNDaysBetweenActivitiesForm(ConstraintMinNDaysBetweenActivities* ctr);
 	~ModifyConstraintMinNDaysBetweenActivitiesForm();
 
-	void updateActivitiesListBox();
+	void filterChanged();
 	
 	void addActivity();
 	void removeActivity();
@@ -51,6 +51,8 @@ public:
 	void ok();
 	void cancel();
 	
+	bool filterOk(Activity* ac);
+	
 private:
 	ConstraintMinNDaysBetweenActivities* _ctr;
 	//the id's of the activities listed in the activities list
