@@ -1,8 +1,8 @@
 /***************************************************************************
                           modifyconstraintstudentssetintervalmaxdaysperweekform.h  -  description
                              -------------------
-    begin                : Feb 11, 2005
-    copyright            : (C) 2005 by Lalescu Liviu
+    begin                : 2008
+    copyright            : (C) 2008 by Lalescu Liviu
     email                : Please see http://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
  ***************************************************************************/
 
@@ -19,28 +19,29 @@
 #define MODIFYCONSTRAINTSTUDENTSSETINTERVALMAXDAYSPERWEEKFORM_H
 
 #include "modifyconstraintstudentssetintervalmaxdaysperweekform_template.h"
-#include "genetictimetable_defs.h"
-#include "genetictimetable.h"
+#include "timetable_defs.h"
+#include "timetable.h"
 #include "fet.h"
-#include "fetmainform.h"
+//#include "fetmainform.h"
 
-#include <qcombobox.h>
+#include <q3combobox.h>
 #include <qmessagebox.h>
-#include <qgroupbox.h>
+#include <q3groupbox.h>
 #include <qspinbox.h>
 #include <qcheckbox.h>
 #include <qpushbutton.h>
 #include <qlineedit.h>
-#include <qtextedit.h>
+#include <q3textedit.h>
 
 class ModifyConstraintStudentsSetIntervalMaxDaysPerWeekForm : public ModifyConstraintStudentsSetIntervalMaxDaysPerWeekForm_template  {
+	Q_OBJECT
 public:
 	ConstraintStudentsSetIntervalMaxDaysPerWeek* _ctr;
 
 	ModifyConstraintStudentsSetIntervalMaxDaysPerWeekForm(ConstraintStudentsSetIntervalMaxDaysPerWeek* ctr);
 	~ModifyConstraintStudentsSetIntervalMaxDaysPerWeekForm();
 
-	void updatePeriodGroupBox();
+	void updateMaxDaysSpinBox();
 	void updateStudentsComboBox();
 
 	void constraintChanged();
